package net.minecraft.src;

import net.minecraft.client.Minecraft;
import org.lwjgl.opengl.GL11;
import org.lwjgl.opengl.GL12;
import org.lwjgl.opengl.GL13;

public class GuiResidentsListSlot extends GuiSlot
{
    protected Minecraft mc;
    private EntityPlayer player;
    public GuiResidentsList ownerGui;
    private float xSize_lo;
    private float ySize_lo;
    private int selected;

    public GuiResidentsListSlot(Minecraft var1, GuiResidentsList var2, EntityPlayer parPlayer)
    {
        super(var1, var2.width, var2.height, 32, var2.height - 52, 36);
        this.ownerGui = var2;
        this.mc = var1;
        this.player = parPlayer;
    }

    /**
     * Gets the size of the current slot list.
     */
    protected int getSize()
    {
        return ownerGui.nameplateListDistance.size();
    }

    /**
     * return the height of the content being scrolled
     */
    protected int getContentHeight()
    {
        return this.getSize() * 36;
    }

    /**
     * the element in the slot that was clicked, boolean for wether it was double clicked or not
     */
    protected void elementClicked(int var1, boolean var2)
    {
        this.selected = var1;
    }

    /**
     * returns true if the element passed in is currently selected
     */
    protected boolean isSelected(int var1)
    {
        return this.selected == var1;
    }

    protected void drawBackground()
    {
        this.ownerGui.drawDefaultBackground();
    }

    /**
     * draws the slot to the screen, pass in mouse's current x and y and partial ticks
     */
    public void drawScreen(int var1, int var2, float var3)
    {
        super.drawScreen(var1, var2, var3);
        this.xSize_lo = (float)var1;
        this.ySize_lo = (float)var2;
    }

    protected void drawSlot(int index, int x, int y, int var4, Tessellator var5)
    {
        EntityNameplate nameplate = ownerGui.nameplateListDistance.get(index);

        this.ownerGui.drawString(this.ownerGui.fontRenderer, nameplate.petName, x + 70, y + 4, 16777215);
        this.ownerGui.drawString(this.ownerGui.fontRenderer, nameplate.ownerClass, x + 78, y + 14, 16777215);

        EntityLiving plateOwner = nameplate.entityOwner;

        if(plateOwner == null)
        {
            this.ownerGui.drawString(this.ownerGui.fontRenderer, "NoEntity", x + 15, y + 12, 16777215);
        }
        else
        {
            this.ownerGui.drawString(this.ownerGui.fontRenderer, String.format(
                "X:%.0f Y:%.0f Z:%.0f Dist:%.3f",
                new Object[] {
                    nameplate.entityOwner.posX,
                    nameplate.entityOwner.posY,
                    nameplate.entityOwner.posZ,
                    this.player.getDistanceToEntity(nameplate.entityOwner)
                }
            ), x + 78, y + 24, 16777215);
            GL11.glEnable(GL12.GL_RESCALE_NORMAL);
            GL11.glEnable(GL11.GL_COLOR_MATERIAL);
            GL11.glPushMatrix();
            float var10 = 15.0F;

            if (plateOwner.height > 2.0F)
            {
                var10 = var10 * 2.0F / plateOwner.height;
            }

            GL11.glTranslatef((float)(x + 30), (float)(y + 30), 50.0F + var10);
            GL11.glScalef(-var10, var10, var10);
            GL11.glRotatef(180.0F, 0.0F, 0.0F, 1.0F);
            float var11 = (float)(x + 30) - this.xSize_lo;
            float var12 = (float)(y + 30 - 10) - this.ySize_lo;
            GL11.glRotatef(135.0F, 0.0F, 1.0F, 0.0F);
            RenderHelper.enableStandardItemLighting();
            GL11.glRotatef(-135.0F, 0.0F, 1.0F, 0.0F);
            GL11.glRotatef(-((float)Math.atan((double)(var12 / 40.0F))) * 20.0F, 1.0F, 0.0F, 0.0F);
            plateOwner.renderYawOffset = (float)Math.atan((double)(var11 / 40.0F)) * 20.0F;
            plateOwner.rotationYaw = (float)Math.atan((double)(var11 / 40.0F)) * 40.0F;
            plateOwner.rotationPitch = -((float)Math.atan((double)(var12 / 40.0F))) * 20.0F;
            plateOwner.prevRotationYawHead = plateOwner.rotationYawHead;
            plateOwner.rotationYawHead = plateOwner.rotationYaw;
            GL11.glTranslatef(0.0F, plateOwner.yOffset, 0.0F);
            RenderManager.instance.playerViewY = 180.0F;

            try
            {
                RenderManager.instance.renderEntityWithPosYaw(plateOwner, 0.0D, 0.0D, 0.0D, 0.0F, 1.0F);
            }
            catch (Exception var14)
            {
            }

            GL13.glMultiTexCoord2f(GL13.GL_TEXTURE1, 240.0F, 240.0F);
            GL11.glPopMatrix();
            RenderHelper.disableStandardItemLighting();
            GL11.glDisable(GL12.GL_RESCALE_NORMAL);
        }
    }
}
